/*******************************************************************************
* File Name: RS422_out.h
* Version 2.50
*
* Description:
*  Contains the function prototypes and constants available to the UART
*  user module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/


#if !defined(CY_UART_RS422_out_H)
#define CY_UART_RS422_out_H

#include "cytypes.h"
#include "cyfitter.h"
#include "CyLib.h"


/***************************************
* Conditional Compilation Parameters
***************************************/

#define RS422_out_RX_ENABLED                     (0u)
#define RS422_out_TX_ENABLED                     (1u)
#define RS422_out_HD_ENABLED                     (0u)
#define RS422_out_RX_INTERRUPT_ENABLED           (0u)
#define RS422_out_TX_INTERRUPT_ENABLED           (1u)
#define RS422_out_INTERNAL_CLOCK_USED            (0u)
#define RS422_out_RXHW_ADDRESS_ENABLED           (1u)
#define RS422_out_OVER_SAMPLE_COUNT              (8u)
#define RS422_out_PARITY_TYPE                    (3u)
#define RS422_out_PARITY_TYPE_SW                 (1u)
#define RS422_out_BREAK_DETECT                   (0u)
#define RS422_out_BREAK_BITS_TX                  (13u)
#define RS422_out_BREAK_BITS_RX                  (13u)
#define RS422_out_TXCLKGEN_DP                    (1u)
#define RS422_out_USE23POLLING                   (1u)
#define RS422_out_FLOW_CONTROL                   (0u)
#define RS422_out_CLK_FREQ                       (0u)
#define RS422_out_TX_BUFFER_SIZE                 (11u)
#define RS422_out_RX_BUFFER_SIZE                 (4u)

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component UART_v2_50 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */

#if defined(RS422_out_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG)
    #define RS422_out_CONTROL_REG_REMOVED            (0u)
#else
    #define RS422_out_CONTROL_REG_REMOVED            (1u)
#endif /* End RS422_out_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG */


/***************************************
*      Data Structure Definition
***************************************/

/* Sleep Mode API Support */
typedef struct RS422_out_backupStruct_
{
    uint8 enableState;

    #if(RS422_out_CONTROL_REG_REMOVED == 0u)
        uint8 cr;
    #endif /* End RS422_out_CONTROL_REG_REMOVED */

} RS422_out_BACKUP_STRUCT;


/***************************************
*       Function Prototypes
***************************************/

void RS422_out_Start(void) ;
void RS422_out_Stop(void) ;
uint8 RS422_out_ReadControlRegister(void) ;
void RS422_out_WriteControlRegister(uint8 control) ;

void RS422_out_Init(void) ;
void RS422_out_Enable(void) ;
void RS422_out_SaveConfig(void) ;
void RS422_out_RestoreConfig(void) ;
void RS422_out_Sleep(void) ;
void RS422_out_Wakeup(void) ;

/* Only if RX is enabled */
#if( (RS422_out_RX_ENABLED) || (RS422_out_HD_ENABLED) )

    #if (RS422_out_RX_INTERRUPT_ENABLED)
        #define RS422_out_EnableRxInt()  CyIntEnable (RS422_out_RX_VECT_NUM)
        #define RS422_out_DisableRxInt() CyIntDisable(RS422_out_RX_VECT_NUM)
        CY_ISR_PROTO(RS422_out_RXISR);
    #endif /* RS422_out_RX_INTERRUPT_ENABLED */

    void RS422_out_SetRxAddressMode(uint8 addressMode)
                                                           ;
    void RS422_out_SetRxAddress1(uint8 address) ;
    void RS422_out_SetRxAddress2(uint8 address) ;

    void  RS422_out_SetRxInterruptMode(uint8 intSrc) ;
    uint8 RS422_out_ReadRxData(void) ;
    uint8 RS422_out_ReadRxStatus(void) ;
    uint8 RS422_out_GetChar(void) ;
    uint16 RS422_out_GetByte(void) ;
    uint8 RS422_out_GetRxBufferSize(void)
                                                            ;
    void RS422_out_ClearRxBuffer(void) ;

    /* Obsolete functions, defines for backward compatible */
    #define RS422_out_GetRxInterruptSource   RS422_out_ReadRxStatus

#endif /* End (RS422_out_RX_ENABLED) || (RS422_out_HD_ENABLED) */

/* Only if TX is enabled */
#if(RS422_out_TX_ENABLED || RS422_out_HD_ENABLED)

    #if(RS422_out_TX_INTERRUPT_ENABLED)
        #define RS422_out_EnableTxInt()  CyIntEnable (RS422_out_TX_VECT_NUM)
        #define RS422_out_DisableTxInt() CyIntDisable(RS422_out_TX_VECT_NUM)
        #define RS422_out_SetPendingTxInt() CyIntSetPending(RS422_out_TX_VECT_NUM)
        #define RS422_out_ClearPendingTxInt() CyIntClearPending(RS422_out_TX_VECT_NUM)
        CY_ISR_PROTO(RS422_out_TXISR);
    #endif /* RS422_out_TX_INTERRUPT_ENABLED */

    void RS422_out_SetTxInterruptMode(uint8 intSrc) ;
    void RS422_out_WriteTxData(uint8 txDataByte) ;
    uint8 RS422_out_ReadTxStatus(void) ;
    void RS422_out_PutChar(uint8 txDataByte) ;
    void RS422_out_PutString(const char8 string[]) ;
    void RS422_out_PutArray(const uint8 string[], uint8 byteCount)
                                                            ;
    void RS422_out_PutCRLF(uint8 txDataByte) ;
    void RS422_out_ClearTxBuffer(void) ;
    void RS422_out_SetTxAddressMode(uint8 addressMode) ;
    void RS422_out_SendBreak(uint8 retMode) ;
    uint8 RS422_out_GetTxBufferSize(void)
                                                            ;
    /* Obsolete functions, defines for backward compatible */
    #define RS422_out_PutStringConst         RS422_out_PutString
    #define RS422_out_PutArrayConst          RS422_out_PutArray
    #define RS422_out_GetTxInterruptSource   RS422_out_ReadTxStatus

#endif /* End RS422_out_TX_ENABLED || RS422_out_HD_ENABLED */

#if(RS422_out_HD_ENABLED)
    void RS422_out_LoadRxConfig(void) ;
    void RS422_out_LoadTxConfig(void) ;
#endif /* End RS422_out_HD_ENABLED */


/* Communication bootloader APIs */
#if defined(CYDEV_BOOTLOADER_IO_COMP) && ((CYDEV_BOOTLOADER_IO_COMP == CyBtldr_RS422_out) || \
                                          (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Custom_Interface))
    /* Physical layer functions */
    void    RS422_out_CyBtldrCommStart(void) CYSMALL ;
    void    RS422_out_CyBtldrCommStop(void) CYSMALL ;
    void    RS422_out_CyBtldrCommReset(void) CYSMALL ;
    cystatus RS422_out_CyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut) CYSMALL
             ;
    cystatus RS422_out_CyBtldrCommRead(uint8 pData[], uint16 size, uint16 * count, uint8 timeOut) CYSMALL
             ;

    #if (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_RS422_out)
        #define CyBtldrCommStart    RS422_out_CyBtldrCommStart
        #define CyBtldrCommStop     RS422_out_CyBtldrCommStop
        #define CyBtldrCommReset    RS422_out_CyBtldrCommReset
        #define CyBtldrCommWrite    RS422_out_CyBtldrCommWrite
        #define CyBtldrCommRead     RS422_out_CyBtldrCommRead
    #endif  /* (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_RS422_out) */

    /* Byte to Byte time out for detecting end of block data from host */
    #define RS422_out_BYTE2BYTE_TIME_OUT (25u)
    #define RS422_out_PACKET_EOP         (0x17u) /* End of packet defined by bootloader */
    #define RS422_out_WAIT_EOP_DELAY     (5u)    /* Additional 5ms to wait for End of packet */
    #define RS422_out_BL_CHK_DELAY_MS    (1u)    /* Time Out quantity equal 1mS */

#endif /* CYDEV_BOOTLOADER_IO_COMP */


/***************************************
*          API Constants
***************************************/
/* Parameters for SetTxAddressMode API*/
#define RS422_out_SET_SPACE      (0x00u)
#define RS422_out_SET_MARK       (0x01u)

/* Status Register definitions */
#if( (RS422_out_TX_ENABLED) || (RS422_out_HD_ENABLED) )
    #if(RS422_out_TX_INTERRUPT_ENABLED)
        #define RS422_out_TX_VECT_NUM            (uint8)RS422_out_TXInternalInterrupt__INTC_NUMBER
        #define RS422_out_TX_PRIOR_NUM           (uint8)RS422_out_TXInternalInterrupt__INTC_PRIOR_NUM
    #endif /* RS422_out_TX_INTERRUPT_ENABLED */

    #define RS422_out_TX_STS_COMPLETE_SHIFT          (0x00u)
    #define RS422_out_TX_STS_FIFO_EMPTY_SHIFT        (0x01u)
    #define RS422_out_TX_STS_FIFO_NOT_FULL_SHIFT     (0x03u)
    #if(RS422_out_TX_ENABLED)
        #define RS422_out_TX_STS_FIFO_FULL_SHIFT     (0x02u)
    #else /* (RS422_out_HD_ENABLED) */
        #define RS422_out_TX_STS_FIFO_FULL_SHIFT     (0x05u)  /* Needs MD=0 */
    #endif /* (RS422_out_TX_ENABLED) */

    #define RS422_out_TX_STS_COMPLETE            (uint8)(0x01u << RS422_out_TX_STS_COMPLETE_SHIFT)
    #define RS422_out_TX_STS_FIFO_EMPTY          (uint8)(0x01u << RS422_out_TX_STS_FIFO_EMPTY_SHIFT)
    #define RS422_out_TX_STS_FIFO_FULL           (uint8)(0x01u << RS422_out_TX_STS_FIFO_FULL_SHIFT)
    #define RS422_out_TX_STS_FIFO_NOT_FULL       (uint8)(0x01u << RS422_out_TX_STS_FIFO_NOT_FULL_SHIFT)
#endif /* End (RS422_out_TX_ENABLED) || (RS422_out_HD_ENABLED)*/

#if( (RS422_out_RX_ENABLED) || (RS422_out_HD_ENABLED) )
    #if(RS422_out_RX_INTERRUPT_ENABLED)
        #define RS422_out_RX_VECT_NUM            (uint8)RS422_out_RXInternalInterrupt__INTC_NUMBER
        #define RS422_out_RX_PRIOR_NUM           (uint8)RS422_out_RXInternalInterrupt__INTC_PRIOR_NUM
    #endif /* RS422_out_RX_INTERRUPT_ENABLED */
    #define RS422_out_RX_STS_MRKSPC_SHIFT            (0x00u)
    #define RS422_out_RX_STS_BREAK_SHIFT             (0x01u)
    #define RS422_out_RX_STS_PAR_ERROR_SHIFT         (0x02u)
    #define RS422_out_RX_STS_STOP_ERROR_SHIFT        (0x03u)
    #define RS422_out_RX_STS_OVERRUN_SHIFT           (0x04u)
    #define RS422_out_RX_STS_FIFO_NOTEMPTY_SHIFT     (0x05u)
    #define RS422_out_RX_STS_ADDR_MATCH_SHIFT        (0x06u)
    #define RS422_out_RX_STS_SOFT_BUFF_OVER_SHIFT    (0x07u)

    #define RS422_out_RX_STS_MRKSPC           (uint8)(0x01u << RS422_out_RX_STS_MRKSPC_SHIFT)
    #define RS422_out_RX_STS_BREAK            (uint8)(0x01u << RS422_out_RX_STS_BREAK_SHIFT)
    #define RS422_out_RX_STS_PAR_ERROR        (uint8)(0x01u << RS422_out_RX_STS_PAR_ERROR_SHIFT)
    #define RS422_out_RX_STS_STOP_ERROR       (uint8)(0x01u << RS422_out_RX_STS_STOP_ERROR_SHIFT)
    #define RS422_out_RX_STS_OVERRUN          (uint8)(0x01u << RS422_out_RX_STS_OVERRUN_SHIFT)
    #define RS422_out_RX_STS_FIFO_NOTEMPTY    (uint8)(0x01u << RS422_out_RX_STS_FIFO_NOTEMPTY_SHIFT)
    #define RS422_out_RX_STS_ADDR_MATCH       (uint8)(0x01u << RS422_out_RX_STS_ADDR_MATCH_SHIFT)
    #define RS422_out_RX_STS_SOFT_BUFF_OVER   (uint8)(0x01u << RS422_out_RX_STS_SOFT_BUFF_OVER_SHIFT)
    #define RS422_out_RX_HW_MASK                     (0x7Fu)
#endif /* End (RS422_out_RX_ENABLED) || (RS422_out_HD_ENABLED) */

/* Control Register definitions */
#define RS422_out_CTRL_HD_SEND_SHIFT                 (0x00u) /* 1 enable TX part in Half Duplex mode */
#define RS422_out_CTRL_HD_SEND_BREAK_SHIFT           (0x01u) /* 1 send BREAK signal in Half Duplez mode */
#define RS422_out_CTRL_MARK_SHIFT                    (0x02u) /* 1 sets mark, 0 sets space */
#define RS422_out_CTRL_PARITY_TYPE0_SHIFT            (0x03u) /* Defines the type of parity implemented */
#define RS422_out_CTRL_PARITY_TYPE1_SHIFT            (0x04u) /* Defines the type of parity implemented */
#define RS422_out_CTRL_RXADDR_MODE0_SHIFT            (0x05u)
#define RS422_out_CTRL_RXADDR_MODE1_SHIFT            (0x06u)
#define RS422_out_CTRL_RXADDR_MODE2_SHIFT            (0x07u)

#define RS422_out_CTRL_HD_SEND               (uint8)(0x01u << RS422_out_CTRL_HD_SEND_SHIFT)
#define RS422_out_CTRL_HD_SEND_BREAK         (uint8)(0x01u << RS422_out_CTRL_HD_SEND_BREAK_SHIFT)
#define RS422_out_CTRL_MARK                  (uint8)(0x01u << RS422_out_CTRL_MARK_SHIFT)
#define RS422_out_CTRL_PARITY_TYPE_MASK      (uint8)(0x03u << RS422_out_CTRL_PARITY_TYPE0_SHIFT)
#define RS422_out_CTRL_RXADDR_MODE_MASK      (uint8)(0x07u << RS422_out_CTRL_RXADDR_MODE0_SHIFT)

/* StatusI Register Interrupt Enable Control Bits. As defined by the Register map for the AUX Control Register */
#define RS422_out_INT_ENABLE                         (0x10u)

/* Bit Counter (7-bit) Control Register Bit Definitions. As defined by the Register map for the AUX Control Register */
#define RS422_out_CNTR_ENABLE                        (0x20u)

/*   Constants for SendBreak() "retMode" parameter  */
#define RS422_out_SEND_BREAK                         (0x00u)
#define RS422_out_WAIT_FOR_COMPLETE_REINIT           (0x01u)
#define RS422_out_REINIT                             (0x02u)
#define RS422_out_SEND_WAIT_REINIT                   (0x03u)

#define RS422_out_OVER_SAMPLE_8                      (8u)
#define RS422_out_OVER_SAMPLE_16                     (16u)

#define RS422_out_BIT_CENTER                         (RS422_out_OVER_SAMPLE_COUNT - 2u)

#define RS422_out_FIFO_LENGTH                        (4u)
#define RS422_out_NUMBER_OF_START_BIT                (1u)
#define RS422_out_MAX_BYTE_VALUE                     (0xFFu)

/* 8X always for count7 implementation */
#define RS422_out_TXBITCTR_BREAKBITS8X   ((RS422_out_BREAK_BITS_TX * RS422_out_OVER_SAMPLE_8) - 1u)
/* 8X or 16X for DP implementation */
#define RS422_out_TXBITCTR_BREAKBITS ((RS422_out_BREAK_BITS_TX * RS422_out_OVER_SAMPLE_COUNT) - 1u)

#define RS422_out_HALF_BIT_COUNT   \
                            (((RS422_out_OVER_SAMPLE_COUNT / 2u) + (RS422_out_USE23POLLING * 1u)) - 2u)
#if (RS422_out_OVER_SAMPLE_COUNT == RS422_out_OVER_SAMPLE_8)
    #define RS422_out_HD_TXBITCTR_INIT   (((RS422_out_BREAK_BITS_TX + \
                            RS422_out_NUMBER_OF_START_BIT) * RS422_out_OVER_SAMPLE_COUNT) - 1u)

    /* This parameter is increased on the 2 in 2 out of 3 mode to sample voting in the middle */
    #define RS422_out_RXBITCTR_INIT  ((((RS422_out_BREAK_BITS_RX + RS422_out_NUMBER_OF_START_BIT) \
                            * RS422_out_OVER_SAMPLE_COUNT) + RS422_out_HALF_BIT_COUNT) - 1u)

#else /* RS422_out_OVER_SAMPLE_COUNT == RS422_out_OVER_SAMPLE_16 */
    #define RS422_out_HD_TXBITCTR_INIT   ((8u * RS422_out_OVER_SAMPLE_COUNT) - 1u)
    /* 7bit counter need one more bit for OverSampleCount = 16 */
    #define RS422_out_RXBITCTR_INIT      (((7u * RS422_out_OVER_SAMPLE_COUNT) - 1u) + \
                                                      RS422_out_HALF_BIT_COUNT)
#endif /* End RS422_out_OVER_SAMPLE_COUNT */

#define RS422_out_HD_RXBITCTR_INIT                   RS422_out_RXBITCTR_INIT


/***************************************
* Global variables external identifier
***************************************/

extern uint8 RS422_out_initVar;
#if (RS422_out_TX_INTERRUPT_ENABLED && RS422_out_TX_ENABLED)
    extern volatile uint8 RS422_out_txBuffer[RS422_out_TX_BUFFER_SIZE];
    extern volatile uint8 RS422_out_txBufferRead;
    extern uint8 RS422_out_txBufferWrite;
#endif /* (RS422_out_TX_INTERRUPT_ENABLED && RS422_out_TX_ENABLED) */
#if (RS422_out_RX_INTERRUPT_ENABLED && (RS422_out_RX_ENABLED || RS422_out_HD_ENABLED))
    extern uint8 RS422_out_errorStatus;
    extern volatile uint8 RS422_out_rxBuffer[RS422_out_RX_BUFFER_SIZE];
    extern volatile uint8 RS422_out_rxBufferRead;
    extern volatile uint8 RS422_out_rxBufferWrite;
    extern volatile uint8 RS422_out_rxBufferLoopDetect;
    extern volatile uint8 RS422_out_rxBufferOverflow;
    #if (RS422_out_RXHW_ADDRESS_ENABLED)
        extern volatile uint8 RS422_out_rxAddressMode;
        extern volatile uint8 RS422_out_rxAddressDetected;
    #endif /* (RS422_out_RXHW_ADDRESS_ENABLED) */
#endif /* (RS422_out_RX_INTERRUPT_ENABLED && (RS422_out_RX_ENABLED || RS422_out_HD_ENABLED)) */


/***************************************
* Enumerated Types and Parameters
***************************************/

#define RS422_out__B_UART__AM_SW_BYTE_BYTE 1
#define RS422_out__B_UART__AM_SW_DETECT_TO_BUFFER 2
#define RS422_out__B_UART__AM_HW_BYTE_BY_BYTE 3
#define RS422_out__B_UART__AM_HW_DETECT_TO_BUFFER 4
#define RS422_out__B_UART__AM_NONE 0

#define RS422_out__B_UART__NONE_REVB 0
#define RS422_out__B_UART__EVEN_REVB 1
#define RS422_out__B_UART__ODD_REVB 2
#define RS422_out__B_UART__MARK_SPACE_REVB 3



/***************************************
*    Initial Parameter Constants
***************************************/

/* UART shifts max 8 bits, Mark/Space functionality working if 9 selected */
#define RS422_out_NUMBER_OF_DATA_BITS    ((9u > 8u) ? 8u : 9u)
#define RS422_out_NUMBER_OF_STOP_BITS    (1u)

#if (RS422_out_RXHW_ADDRESS_ENABLED)
    #define RS422_out_RX_ADDRESS_MODE    (1u)
    #define RS422_out_RX_HW_ADDRESS1     (49u)
    #define RS422_out_RX_HW_ADDRESS2     (33u)
#endif /* (RS422_out_RXHW_ADDRESS_ENABLED) */

#define RS422_out_INIT_RX_INTERRUPTS_MASK \
                                  (uint8)((0 << RS422_out_RX_STS_FIFO_NOTEMPTY_SHIFT) \
                                        | (0 << RS422_out_RX_STS_MRKSPC_SHIFT) \
                                        | (0 << RS422_out_RX_STS_ADDR_MATCH_SHIFT) \
                                        | (0 << RS422_out_RX_STS_PAR_ERROR_SHIFT) \
                                        | (0 << RS422_out_RX_STS_STOP_ERROR_SHIFT) \
                                        | (0 << RS422_out_RX_STS_BREAK_SHIFT) \
                                        | (0 << RS422_out_RX_STS_OVERRUN_SHIFT))

#define RS422_out_INIT_TX_INTERRUPTS_MASK \
                                  (uint8)((0 << RS422_out_TX_STS_COMPLETE_SHIFT) \
                                        | (1 << RS422_out_TX_STS_FIFO_EMPTY_SHIFT) \
                                        | (0 << RS422_out_TX_STS_FIFO_FULL_SHIFT) \
                                        | (0 << RS422_out_TX_STS_FIFO_NOT_FULL_SHIFT))


/***************************************
*              Registers
***************************************/

#ifdef RS422_out_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG
    #define RS422_out_CONTROL_REG \
                            (* (reg8 *) RS422_out_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG )
    #define RS422_out_CONTROL_PTR \
                            (  (reg8 *) RS422_out_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG )
#endif /* End RS422_out_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG */

#if(RS422_out_TX_ENABLED)
    #define RS422_out_TXDATA_REG          (* (reg8 *) RS422_out_BUART_sTX_TxShifter_u0__F0_REG)
    #define RS422_out_TXDATA_PTR          (  (reg8 *) RS422_out_BUART_sTX_TxShifter_u0__F0_REG)
    #define RS422_out_TXDATA_AUX_CTL_REG  (* (reg8 *) RS422_out_BUART_sTX_TxShifter_u0__DP_AUX_CTL_REG)
    #define RS422_out_TXDATA_AUX_CTL_PTR  (  (reg8 *) RS422_out_BUART_sTX_TxShifter_u0__DP_AUX_CTL_REG)
    #define RS422_out_TXSTATUS_REG        (* (reg8 *) RS422_out_BUART_sTX_TxSts__STATUS_REG)
    #define RS422_out_TXSTATUS_PTR        (  (reg8 *) RS422_out_BUART_sTX_TxSts__STATUS_REG)
    #define RS422_out_TXSTATUS_MASK_REG   (* (reg8 *) RS422_out_BUART_sTX_TxSts__MASK_REG)
    #define RS422_out_TXSTATUS_MASK_PTR   (  (reg8 *) RS422_out_BUART_sTX_TxSts__MASK_REG)
    #define RS422_out_TXSTATUS_ACTL_REG   (* (reg8 *) RS422_out_BUART_sTX_TxSts__STATUS_AUX_CTL_REG)
    #define RS422_out_TXSTATUS_ACTL_PTR   (  (reg8 *) RS422_out_BUART_sTX_TxSts__STATUS_AUX_CTL_REG)

    /* DP clock */
    #if(RS422_out_TXCLKGEN_DP)
        #define RS422_out_TXBITCLKGEN_CTR_REG        \
                                        (* (reg8 *) RS422_out_BUART_sTX_sCLOCK_TxBitClkGen__D0_REG)
        #define RS422_out_TXBITCLKGEN_CTR_PTR        \
                                        (  (reg8 *) RS422_out_BUART_sTX_sCLOCK_TxBitClkGen__D0_REG)
        #define RS422_out_TXBITCLKTX_COMPLETE_REG    \
                                        (* (reg8 *) RS422_out_BUART_sTX_sCLOCK_TxBitClkGen__D1_REG)
        #define RS422_out_TXBITCLKTX_COMPLETE_PTR    \
                                        (  (reg8 *) RS422_out_BUART_sTX_sCLOCK_TxBitClkGen__D1_REG)
    #else     /* Count7 clock*/
        #define RS422_out_TXBITCTR_PERIOD_REG    \
                                        (* (reg8 *) RS422_out_BUART_sTX_sCLOCK_TxBitCounter__PERIOD_REG)
        #define RS422_out_TXBITCTR_PERIOD_PTR    \
                                        (  (reg8 *) RS422_out_BUART_sTX_sCLOCK_TxBitCounter__PERIOD_REG)
        #define RS422_out_TXBITCTR_CONTROL_REG   \
                                        (* (reg8 *) RS422_out_BUART_sTX_sCLOCK_TxBitCounter__CONTROL_AUX_CTL_REG)
        #define RS422_out_TXBITCTR_CONTROL_PTR   \
                                        (  (reg8 *) RS422_out_BUART_sTX_sCLOCK_TxBitCounter__CONTROL_AUX_CTL_REG)
        #define RS422_out_TXBITCTR_COUNTER_REG   \
                                        (* (reg8 *) RS422_out_BUART_sTX_sCLOCK_TxBitCounter__COUNT_REG)
        #define RS422_out_TXBITCTR_COUNTER_PTR   \
                                        (  (reg8 *) RS422_out_BUART_sTX_sCLOCK_TxBitCounter__COUNT_REG)
    #endif /* RS422_out_TXCLKGEN_DP */

#endif /* End RS422_out_TX_ENABLED */

#if(RS422_out_HD_ENABLED)

    #define RS422_out_TXDATA_REG             (* (reg8 *) RS422_out_BUART_sRX_RxShifter_u0__F1_REG )
    #define RS422_out_TXDATA_PTR             (  (reg8 *) RS422_out_BUART_sRX_RxShifter_u0__F1_REG )
    #define RS422_out_TXDATA_AUX_CTL_REG     (* (reg8 *) RS422_out_BUART_sRX_RxShifter_u0__DP_AUX_CTL_REG)
    #define RS422_out_TXDATA_AUX_CTL_PTR     (  (reg8 *) RS422_out_BUART_sRX_RxShifter_u0__DP_AUX_CTL_REG)

    #define RS422_out_TXSTATUS_REG           (* (reg8 *) RS422_out_BUART_sRX_RxSts__STATUS_REG )
    #define RS422_out_TXSTATUS_PTR           (  (reg8 *) RS422_out_BUART_sRX_RxSts__STATUS_REG )
    #define RS422_out_TXSTATUS_MASK_REG      (* (reg8 *) RS422_out_BUART_sRX_RxSts__MASK_REG )
    #define RS422_out_TXSTATUS_MASK_PTR      (  (reg8 *) RS422_out_BUART_sRX_RxSts__MASK_REG )
    #define RS422_out_TXSTATUS_ACTL_REG      (* (reg8 *) RS422_out_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
    #define RS422_out_TXSTATUS_ACTL_PTR      (  (reg8 *) RS422_out_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
#endif /* End RS422_out_HD_ENABLED */

#if( (RS422_out_RX_ENABLED) || (RS422_out_HD_ENABLED) )
    #define RS422_out_RXDATA_REG             (* (reg8 *) RS422_out_BUART_sRX_RxShifter_u0__F0_REG )
    #define RS422_out_RXDATA_PTR             (  (reg8 *) RS422_out_BUART_sRX_RxShifter_u0__F0_REG )
    #define RS422_out_RXADDRESS1_REG         (* (reg8 *) RS422_out_BUART_sRX_RxShifter_u0__D0_REG )
    #define RS422_out_RXADDRESS1_PTR         (  (reg8 *) RS422_out_BUART_sRX_RxShifter_u0__D0_REG )
    #define RS422_out_RXADDRESS2_REG         (* (reg8 *) RS422_out_BUART_sRX_RxShifter_u0__D1_REG )
    #define RS422_out_RXADDRESS2_PTR         (  (reg8 *) RS422_out_BUART_sRX_RxShifter_u0__D1_REG )
    #define RS422_out_RXDATA_AUX_CTL_REG     (* (reg8 *) RS422_out_BUART_sRX_RxShifter_u0__DP_AUX_CTL_REG)

    #define RS422_out_RXBITCTR_PERIOD_REG    (* (reg8 *) RS422_out_BUART_sRX_RxBitCounter__PERIOD_REG )
    #define RS422_out_RXBITCTR_PERIOD_PTR    (  (reg8 *) RS422_out_BUART_sRX_RxBitCounter__PERIOD_REG )
    #define RS422_out_RXBITCTR_CONTROL_REG   \
                                        (* (reg8 *) RS422_out_BUART_sRX_RxBitCounter__CONTROL_AUX_CTL_REG )
    #define RS422_out_RXBITCTR_CONTROL_PTR   \
                                        (  (reg8 *) RS422_out_BUART_sRX_RxBitCounter__CONTROL_AUX_CTL_REG )
    #define RS422_out_RXBITCTR_COUNTER_REG   (* (reg8 *) RS422_out_BUART_sRX_RxBitCounter__COUNT_REG )
    #define RS422_out_RXBITCTR_COUNTER_PTR   (  (reg8 *) RS422_out_BUART_sRX_RxBitCounter__COUNT_REG )

    #define RS422_out_RXSTATUS_REG           (* (reg8 *) RS422_out_BUART_sRX_RxSts__STATUS_REG )
    #define RS422_out_RXSTATUS_PTR           (  (reg8 *) RS422_out_BUART_sRX_RxSts__STATUS_REG )
    #define RS422_out_RXSTATUS_MASK_REG      (* (reg8 *) RS422_out_BUART_sRX_RxSts__MASK_REG )
    #define RS422_out_RXSTATUS_MASK_PTR      (  (reg8 *) RS422_out_BUART_sRX_RxSts__MASK_REG )
    #define RS422_out_RXSTATUS_ACTL_REG      (* (reg8 *) RS422_out_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
    #define RS422_out_RXSTATUS_ACTL_PTR      (  (reg8 *) RS422_out_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
#endif /* End  (RS422_out_RX_ENABLED) || (RS422_out_HD_ENABLED) */

#if(RS422_out_INTERNAL_CLOCK_USED)
    /* Register to enable or disable the digital clocks */
    #define RS422_out_INTCLOCK_CLKEN_REG     (* (reg8 *) RS422_out_IntClock__PM_ACT_CFG)
    #define RS422_out_INTCLOCK_CLKEN_PTR     (  (reg8 *) RS422_out_IntClock__PM_ACT_CFG)

    /* Clock mask for this clock. */
    #define RS422_out_INTCLOCK_CLKEN_MASK    RS422_out_IntClock__PM_ACT_MSK
#endif /* End RS422_out_INTERNAL_CLOCK_USED */


/***************************************
*       Register Constants
***************************************/

#if(RS422_out_TX_ENABLED)
    #define RS422_out_TX_FIFO_CLR            (0x01u) /* FIFO0 CLR */
#endif /* End RS422_out_TX_ENABLED */

#if(RS422_out_HD_ENABLED)
    #define RS422_out_TX_FIFO_CLR            (0x02u) /* FIFO1 CLR */
#endif /* End RS422_out_HD_ENABLED */

#if( (RS422_out_RX_ENABLED) || (RS422_out_HD_ENABLED) )
    #define RS422_out_RX_FIFO_CLR            (0x01u) /* FIFO0 CLR */
#endif /* End  (RS422_out_RX_ENABLED) || (RS422_out_HD_ENABLED) */


/***************************************
* The following code is DEPRECATED and
* should not be used in new projects.
***************************************/

/* UART v2_40 obsolete definitions */
#define RS422_out_WAIT_1_MS      RS422_out_BL_CHK_DELAY_MS   

#define RS422_out_TXBUFFERSIZE   RS422_out_TX_BUFFER_SIZE
#define RS422_out_RXBUFFERSIZE   RS422_out_RX_BUFFER_SIZE

#if (RS422_out_RXHW_ADDRESS_ENABLED)
    #define RS422_out_RXADDRESSMODE  RS422_out_RX_ADDRESS_MODE
    #define RS422_out_RXHWADDRESS1   RS422_out_RX_HW_ADDRESS1
    #define RS422_out_RXHWADDRESS2   RS422_out_RX_HW_ADDRESS2
    /* Backward compatible define */
    #define RS422_out_RXAddressMode  RS422_out_RXADDRESSMODE
#endif /* (RS422_out_RXHW_ADDRESS_ENABLED) */

/* UART v2_30 obsolete definitions */
#define RS422_out_initvar                    RS422_out_initVar

#define RS422_out_RX_Enabled                 RS422_out_RX_ENABLED
#define RS422_out_TX_Enabled                 RS422_out_TX_ENABLED
#define RS422_out_HD_Enabled                 RS422_out_HD_ENABLED
#define RS422_out_RX_IntInterruptEnabled     RS422_out_RX_INTERRUPT_ENABLED
#define RS422_out_TX_IntInterruptEnabled     RS422_out_TX_INTERRUPT_ENABLED
#define RS422_out_InternalClockUsed          RS422_out_INTERNAL_CLOCK_USED
#define RS422_out_RXHW_Address_Enabled       RS422_out_RXHW_ADDRESS_ENABLED
#define RS422_out_OverSampleCount            RS422_out_OVER_SAMPLE_COUNT
#define RS422_out_ParityType                 RS422_out_PARITY_TYPE

#if( RS422_out_TX_ENABLED && (RS422_out_TXBUFFERSIZE > RS422_out_FIFO_LENGTH))
    #define RS422_out_TXBUFFER               RS422_out_txBuffer
    #define RS422_out_TXBUFFERREAD           RS422_out_txBufferRead
    #define RS422_out_TXBUFFERWRITE          RS422_out_txBufferWrite
#endif /* End RS422_out_TX_ENABLED */
#if( ( RS422_out_RX_ENABLED || RS422_out_HD_ENABLED ) && \
     (RS422_out_RXBUFFERSIZE > RS422_out_FIFO_LENGTH) )
    #define RS422_out_RXBUFFER               RS422_out_rxBuffer
    #define RS422_out_RXBUFFERREAD           RS422_out_rxBufferRead
    #define RS422_out_RXBUFFERWRITE          RS422_out_rxBufferWrite
    #define RS422_out_RXBUFFERLOOPDETECT     RS422_out_rxBufferLoopDetect
    #define RS422_out_RXBUFFER_OVERFLOW      RS422_out_rxBufferOverflow
#endif /* End RS422_out_RX_ENABLED */

#ifdef RS422_out_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG
    #define RS422_out_CONTROL                RS422_out_CONTROL_REG
#endif /* End RS422_out_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG */

#if(RS422_out_TX_ENABLED)
    #define RS422_out_TXDATA                 RS422_out_TXDATA_REG
    #define RS422_out_TXSTATUS               RS422_out_TXSTATUS_REG
    #define RS422_out_TXSTATUS_MASK          RS422_out_TXSTATUS_MASK_REG
    #define RS422_out_TXSTATUS_ACTL          RS422_out_TXSTATUS_ACTL_REG
    /* DP clock */
    #if(RS422_out_TXCLKGEN_DP)
        #define RS422_out_TXBITCLKGEN_CTR        RS422_out_TXBITCLKGEN_CTR_REG
        #define RS422_out_TXBITCLKTX_COMPLETE    RS422_out_TXBITCLKTX_COMPLETE_REG
    #else     /* Count7 clock*/
        #define RS422_out_TXBITCTR_PERIOD        RS422_out_TXBITCTR_PERIOD_REG
        #define RS422_out_TXBITCTR_CONTROL       RS422_out_TXBITCTR_CONTROL_REG
        #define RS422_out_TXBITCTR_COUNTER       RS422_out_TXBITCTR_COUNTER_REG
    #endif /* RS422_out_TXCLKGEN_DP */
#endif /* End RS422_out_TX_ENABLED */

#if(RS422_out_HD_ENABLED)
    #define RS422_out_TXDATA                 RS422_out_TXDATA_REG
    #define RS422_out_TXSTATUS               RS422_out_TXSTATUS_REG
    #define RS422_out_TXSTATUS_MASK          RS422_out_TXSTATUS_MASK_REG
    #define RS422_out_TXSTATUS_ACTL          RS422_out_TXSTATUS_ACTL_REG
#endif /* End RS422_out_HD_ENABLED */

#if( (RS422_out_RX_ENABLED) || (RS422_out_HD_ENABLED) )
    #define RS422_out_RXDATA                 RS422_out_RXDATA_REG
    #define RS422_out_RXADDRESS1             RS422_out_RXADDRESS1_REG
    #define RS422_out_RXADDRESS2             RS422_out_RXADDRESS2_REG
    #define RS422_out_RXBITCTR_PERIOD        RS422_out_RXBITCTR_PERIOD_REG
    #define RS422_out_RXBITCTR_CONTROL       RS422_out_RXBITCTR_CONTROL_REG
    #define RS422_out_RXBITCTR_COUNTER       RS422_out_RXBITCTR_COUNTER_REG
    #define RS422_out_RXSTATUS               RS422_out_RXSTATUS_REG
    #define RS422_out_RXSTATUS_MASK          RS422_out_RXSTATUS_MASK_REG
    #define RS422_out_RXSTATUS_ACTL          RS422_out_RXSTATUS_ACTL_REG
#endif /* End  (RS422_out_RX_ENABLED) || (RS422_out_HD_ENABLED) */

#if(RS422_out_INTERNAL_CLOCK_USED)
    #define RS422_out_INTCLOCK_CLKEN         RS422_out_INTCLOCK_CLKEN_REG
#endif /* End RS422_out_INTERNAL_CLOCK_USED */

#define RS422_out_WAIT_FOR_COMLETE_REINIT    RS422_out_WAIT_FOR_COMPLETE_REINIT

#endif  /* CY_UART_RS422_out_H */


/* [] END OF FILE */
